footings_test_module.DocModel — footings_test_module documentation

# footings_test_module.DocModel

class `footings_test_module.` `DocModel`(*, param_1: int, param_2: int, modif_1: int = 1, modif_2: int = 2)

  This is a model to test documentation.

  Parameters
    param_1 `int`

      This is parameter 1.

    param_2 `int`

      This is parameter 2.

  Modifiers
    modif_1 `int`

      This is modifier 1.

    modif_2 `int`

      This is modifier 2.

  Meta
    meta_1

      This is meta 1.

    meta_2

      This is meta 2.

  Assets
    asset_1 `int`

      This is asset 1.

    asset_2 `int`

      This is asset 2.

  Steps

    1. _step_1 - Step 1 summary

    2. _step_2 - Step 2 summary

  Methods

  `audit`(self, file, **kwargs) | Audit the model which returns copies of the object as it is modified across each step.
  `run`(self[, to_step]) | Runs the model and returns any assets defined.
  `visualize`(self) | Visualize the model to get an understanding of what model attributes are used and when.

  `__init__`(self, *, param_1: int, param_2: int, modif_1: int = 1, modif_2: int = 2) → None

    Method generated by attrs for class DocModel.

  Methods

  `__init__`(self, *, param_1, param_2, modif_1, …) | Method generated by attrs for class DocModel.
  `audit`(self, file, **kwargs) | Audit the model which returns copies of the object as it is modified across each step.
  `run`(self[, to_step]) | Runs the model and returns any assets defined.
  `visualize`(self) | Visualize the model to get an understanding of what model attributes are used and when.

  Attributes

  `asset_1` |
  `asset_2` |
  `assets` |
  `meta_1` |
  `meta_2` |
  `modif_1` |
  `modif_2` |
  `param_1` |
  `param_2` |
  `steps` |

  `audit`(self, file: str, **kwargs)

    Audit the model which returns copies of the object as it is modified across each step.

    Parameters
      file `str`

        The name of the audit file.

      kwargs

        Additional key words passed to audit.

    Returns
      `None`

        An audit file in specfified format (e.g., .xlsx).

  `run`(self, to_step=None)

    Runs the model and returns any assets defined.

    Parameters
      to_step `str`

        The name of the step to run model to.

  `visualize`(self)

    Visualize the model to get an understanding of what model attributes are used and when.